#
# spec file for package ghc-optics-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name optics-core
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.4.1.1
Release:        2.2
Summary:        Optics as an abstract interface: core definitions
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-indexed-profunctors-devel
BuildRequires:  ghc-indexed-profunctors-prof
BuildRequires:  ghc-indexed-traversable-devel
BuildRequires:  ghc-indexed-traversable-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}

%description
This package makes it possible to define and use Lenses, Traversals, Prisms and
other optics, using an abstract interface.

This variant provides core definitions with a minimal dependency footprint.
See the '<https://hackage.haskell.org/package/optics optics>' package (and its
dependencies) for documentation and the "batteries-included" variant.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Mon May 13 2024 Peter Simons <psimons@suse.com>
- Update optics-core to version 0.4.1.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Jun 22 2023 Peter Simons <psimons@suse.com>
- Update optics-core to version 0.4.1.1.
  [#] optics-core-0.4.1.1 (2023-06-22)
  * Add INLINE pragmas to small functions that really should inline
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue May 17 2022 Peter Simons <psimons@suse.com>
- Update optics-core to version 0.4.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Mar 22 2022 Peter Simons <psimons@suse.com>
- Update optics-core to version 0.4.1.
  [#] optics-core-0.4.1 (2022-03-22)
  * Add support for GHC-9.2
  * Add `is` ([#410](https://github.com/well-typed/optics/pull/410))
  * Improve error messages related to the `JoinKinds` class
    ([#439](https://github.com/well-typed/optics/pull/439))
  * Port `universeOf`, `cosmosOf`, `paraOf`, `rewriteOf`, `transformOf`,
    `rewriteMOf` and `transformMOf` from `Control.Lens.Plated`
    ([#379](https://github.com/well-typed/optics/pull/379))
  * Add `(%%?)` composition operator
    ([#434](https://github.com/well-typed/optics/pull/434))
* Tue Feb 23 2021 psimons@suse.com
- Update optics-core to version 0.4.
  [#] optics-core-0.4 (2021-02-22)
  * See [migration-guide-0.4.md](https://github.com/well-typed/optics/blob/master/migration-guide-0.4.md) for more details
  * Add support for GHC-9.0
  * Drop support for GHC-8.0
  * The `FunctorWithIndex`, `FoldableWithIndex` and `TraversableWithIndex` type
    classes have been migrated to a new package,
    [`indexed-traversable`](https://hackage.haskell.org/package/indexed-traversable)
    ([#370](https://github.com/well-typed/optics/pull/370))
  * Add `adjoin`, `iadjoin` and `both` to `Optics.[Ix]Traversal`
    ([#332](https://github.com/well-typed/optics/pull/332),
    [#372](https://github.com/well-typed/optics/pull/372))
  * Add `ifst` and `isnd` to `Optics.IxLens`
    ([#389](https://github.com/well-typed/optics/pull/389))
  * Generalize types of `generic`
    ([#376](https://github.com/well-typed/optics/pull/376))
  * Make `chosen` an indexed lens to see which value is traversed
    ([#335](https://github.com/well-typed/optics/pull/335))
  * Remove `GeneralLabelOptic` extensibility mechanism
    ([#361](https://github.com/well-typed/optics/pull/361))
  * Add `gfield`, `gafield`, `gconstructor`, `gposition` and `gplate` for
    generics-based data access
    ([#358](https://github.com/well-typed/optics/pull/358),
    [#361](https://github.com/well-typed/optics/pull/361))
  * Add support for generics-based field lenses and constructor prisms (`gfield`
    and `gconstructor`) to `LabelOptic` so they can be used via `OverloadedLabels`
    ([#361](https://github.com/well-typed/optics/pull/361))
  * Remove unnecessary INLINE pragmas to reduce compile times
    ([#394](https://github.com/well-typed/optics/pull/394))
  * Simplify the type of `(%%)` using new `JoinKinds` and `AppendIndices` classes
    in place of the `Join` and `Append` type families
    ([#397](https://github.com/well-typed/optics/pull/397),
    [#399](https://github.com/well-typed/optics/pull/399))
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Aug 26 2020 psimons@suse.com
- Add optics-core at version 0.3.0.1.
